# How to get started
1) create conda environment from env.yml
2) pip install metabomix in the environment, activate environment
3) From the example folder: run main.py 

# How to add more tools: 
Soon
